@@ -8,7 +8,7 @@
 
 extern "C"
 {
-  void* init_libkatehelloworldplugin()
+  void* init_katehelloworldplugin()
   {
     KGlobal::locale()->insertCatalogue("katehelloworld"); 
     return new KatePluginFactory;
