@@ -20,18 +20,15 @@
 
 #include <qinputdialog.h>
 #include <kaction.h>
-#include <kinstance.h>
-#include <kmessagebox.h>
 #include <klocale.h>
 #include <cassert>
 #include <kdebug.h>
-#include <qstring.h>
 
 extern "C"
 {
-  void* init_libkatehtmltoolsplugin()
+  void* init_katehtmltoolsplugin()
   {
-    KGlobal::locale()->insertCatalogue("katehtmltools"); 
+    KGlobal::locale()->insertCatalogue("katehtmltools");
     return new KatePluginFactory;
   }
 }
@@ -66,7 +63,7 @@ Kate::PluginView *PluginKateHtmlTools::createView (Kate::MainWindow *win)
 {
    Kate::PluginView *view = new Kate::PluginView (this, win);
 
-(void)  new KAction ( i18n("HT&ML Tag..."), "edit_HTML_tag", ALT + Key_Minus, this,
+(void)  new KAction ( i18n("HT&ML Tag..."), /*"edit_HTML_tag",*/ ALT + Key_Minus, this,
                                 SLOT( slotEditHTMLtag() ), view->actionCollection(), "edit_HTML_tag" );
 
    view->setXML( "plugins/katehtmltools/ui.rc" );
@@ -93,8 +90,8 @@ void PluginKateHtmlTools::slotEditHTMLtag()
 
 QString PluginKateHtmlTools::KatePrompt
         (
-        QString strTitle,
-        QString strPrompt,
+        const QString & strTitle,
+        const QString & strPrompt,
         QWidget * that
         )
 {
@@ -108,6 +105,7 @@ QString PluginKateHtmlTools::KatePrompt
 			(
 			strTitle,
 			strPrompt,
+                        QLineEdit::Normal,
 			QString::null,
 			&ok,
 			that
@@ -125,17 +123,14 @@ void PluginKateHtmlTools::slipInHTMLtag (Kate::View & view, QString text)  //  P
   //  We must add a heavy elaborate HTML markup system. Not!
 
   QStringList list = QStringList::split (' ', text);
-  QString marked (view.markedText ());
-  int preDeleteLine = -1, preDeleteCol = -1;
-  view.getCursorPosition (&preDeleteLine, &preDeleteCol);
-  assert (preDeleteLine > -1);  assert (preDeleteCol > -1);
-
+  QString marked = view.getDoc()->selection ();
+  uint preDeleteLine = 0, preDeleteCol = 0;
+  view.cursorPosition (&preDeleteLine, &preDeleteCol);
 
   if (marked.length() > 0)
     view.keyDelete ();
-  int line = -1, col = -1;
-  view.getCursorPosition (&line, &col);
-  assert (line > -1);  assert (col > -1);
+  uint line = 0, col = 0;
+  view.cursorPosition (&line, &col);
   QString pre ("<" + text + ">");
   QString post;
   if (list.count () > 0)  post = "</" + list[0] + ">";
