@@ -42,7 +42,7 @@
 
 extern "C"
 {
-  void* init_libkateinsertcommandplugin()
+  void* init_kateinsertcommandplugin()
   {
     KGlobal::locale()->insertCatalogue("kateinsertcommand"); 
     return new KatePluginFactory;
@@ -101,7 +101,7 @@ Kate::PluginView *PluginKateInsertCommand::createView (Kate::MainWindow *win)
 void PluginKateInsertCommand::slotInsertCommand()
 {
   if ( sh && sh->isRunning() ) {
-    KMessageBox::sorry (0, i18n("Sorry, a process is currently beeing executed:("), i18n("Oops!"));
+    KMessageBox::sorry (0, i18n("Sorry, a process is currently being executed:("), i18n("Oops!"));
     return;
   }
 
@@ -291,10 +291,10 @@ CmdPrompt::CmdPrompt(QWidget* parent,
    cb_printCmd->setChecked(settings & 2);
    lo->addWidget( cb_printCmd );
 
-   QWhatsThis::add( cmb_cmd, i18n("Enter the shell command which' output you want inserted into your document. Feel free to use a pipe or two if you're in that mood;-)") );
-   QWhatsThis::add( wdreq, i18n("Sets the working directory of command. The command executed is 'cd <dir> && <command>'") );
-   QWhatsThis::add( cb_insStdErr, i18n("Check this if you want error output from <command> inserted too.\nSome commands like locate prints everything to STDERR") );
-   QWhatsThis::add( cb_printCmd, i18n("If you check this I will print the command string followed by a newline before the output.") );
+   QWhatsThis::add( cmb_cmd, i18n("Enter the shell command, the output of which you want inserted into your document. Feel free to use a pipe or two if you're in that mood;-)") );
+   QWhatsThis::add( wdreq, i18n("Sets the working directory of the command. The command executed is 'cd <dir> && <command>'") );
+   QWhatsThis::add( cb_insStdErr, i18n("Check this if you want the error output from <command> inserted too.\nSome commands, such as locate, print everything to STDERR") );
+   QWhatsThis::add( cb_printCmd, i18n("If you check this, the command string will be printed followed by a newline before the output.") );
 }
 
 CmdPrompt::~CmdPrompt() {}
@@ -310,7 +310,7 @@ WaitDlg::WaitDlg(QWidget* parent, const QString& text, const QString& title)
   setMainWidget( page );
   QHBoxLayout *lo = new QHBoxLayout( page, 0, spacingHint() );
 
-  KAnimWidget *aw = new KAnimWidget( KGlobal::iconLoader()->loadAnimated("kde", 0, 48), 48, page );
+  KAnimWidget *aw = new KAnimWidget( QString::fromLatin1("kde"), 48, page );
   lo->addWidget(aw);
   QLabel *l = new QLabel( text, page );
   lo->addWidget( l );
