@@ -31,7 +31,7 @@
 
 extern "C"
 {
-  void* init_libkateopenheaderplugin()
+  void* init_kateopenheaderplugin()
   {
     KGlobal::locale()->insertCatalogue("kateopenheader"); 
     return new KatePluginFactory;
@@ -68,7 +68,7 @@ Kate::PluginView *PluginKateOpenHeader::createView (Kate::MainWindow *win)
 {
    Kate::PluginView *view = new Kate::PluginView (this, win);
 
-   (void)  new KAction ( i18n("Open .h/[.cpp.c]"), "file_openheader", 0, this,
+   (void)  new KAction ( i18n("Open .h/[.cpp.c]"), /*"file_openheader",*/ 0, this,
   SLOT( slotOpenHeader() ), view->actionCollection(), "file_openheader" );
 
    view->setXML( "plugins/kateopenheader/ui.rc" );
