@@ -8,7 +8,7 @@
 #include <dcopclient.h>
 
 
-	int
+	void
 ShowErrorMessage ( int argc, char** argv, QString strFileName, int nLine, QString strMessage  )
 {
 
