@@ -16,7 +16,7 @@
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
 
-$Id: kolourpicker.cpp,v 1.4 2001/07/11 08:13:13 malte Exp $
+$Id: kolourpicker.cpp,v 1.7 2001/12/11 23:53:55 molnarc Exp $
 */
 
 #include <qfile.h>
@@ -29,6 +29,7 @@ $Id: kolourpicker.cpp,v 1.4 2001/07/11 08:13:13 malte Exp $
 #include <qbitmap.h>
 #include <qpainter.h>
 #include <qtooltip.h>
+#include <qcursor.h>
 
 #include <kglobal.h> 
 #include <klocale.h>
@@ -107,7 +108,7 @@ int KolourPicker::widthForHeight(int height) const
 void KolourPicker::about()
 {
 	KAboutApplication dlg(m_instance->aboutData());
-	dlg.show();
+	dlg.exec();
 }
 
 void KolourPicker::help()
@@ -126,7 +127,7 @@ void KolourPicker::slotHistory()
 {
 	KPopupMenu popup;
 	popup.insertTitle(SmallIcon("colorize"), i18n("History"));
-	QList<QPopupMenu> subMenus;
+	QPtrList<QPopupMenu> subMenus;
 	subMenus.setAutoDelete(true);
 	for (QValueList<QColor>::ConstIterator it = m_history.fromLast();
 		it != m_history.end();
