@@ -263,11 +263,11 @@ void KConfDialog::mouseInteraction(int)
 
   if (!menuOk && !haveWarned) {
     KMessageBox::information(timemon, i18n("KTimeMon notice"),
-			 i18n("You have set the configuration so that\n"
-			      "the pop-up menu cannot be invoked by a\n"
-			      "mouse click. This is probably not such a\n"
-			      "good idea, because you will have to edit\n"
-			      "the configuration options manually to get\n"
+			 i18n("You have set the configuration so that "
+			      "the pop-up menu cannot be invoked by a "
+			      "mouse click. This is probably not such a "
+			      "good idea, because you will have to edit "
+			      "the configuration options manually to get "
 			      "rid of this setting..."));
     haveWarned = true;
   }
