@@ -96,29 +96,29 @@ KSample::KSample(KTimeMon *t, bool a, unsigned p, unsigned s, unsigned c) :
 
   if ((memFD = open(file, O_RDONLY)) == -1) {
     KMessageBox::error(timemon,
-                       i18n("Sorry, I cannot open the file `%1'.\nThe diagnostics are: %2.\n\n"
-                            "I need this file to determine current memory usage.\n"
-                            "Maybe your proc filesystem is non Linux-standard?").arg(file).arg(strerror(errno)));
+                       i18n("Unable to open the file '%1'. The diagnostics are:\n%2.\n"
+                            "This file is required to determine current memory usage.\n"
+                            "Maybe your proc filesystem is non-Linux standard?").arg(file).arg(strerror(errno)));
     exit(1);
   }
 
   snprintf(file, sizeof(file), "%s/%s", proc, STAT_NAME);
   if ((statFD = open(file, O_RDONLY)) == -1) {
     KMessageBox::error(timemon,
-                       i18n("Sorry, I cannot open the file `%1'.\nThe diagnostics are: %2.\n\n"
-                            "I need this file  to determine current system info.\n"
-                            "Maybe your proc filesystem is non Linux-standard?").arg(file).arg(strerror(errno)));
+                       i18n("Unable to open the file '%1'. The diagnostics are:\n%2.\n"
+                            "This file is required to determine current system info. "
+                            "Maybe your proc filesystem is non-Linux standard?").arg(file).arg(strerror(errno)));
     exit(1);
   }
 
 #elif defined (__sun__)
   if ((kc = kstat_open()) == 0) {
-    KMessageBox::error(timemon, i18n("Sorry, I cannot initialise the `kstat' library.\n"
-                                     "This library is used for accessing kernel information.\n"
-                                     "The diagnostics are: `%1'.\n\n"
-                                     "Are you running Solaris at all?\n"
-                                     "You may want to mail me at mueller@kde.org,\n"
-                                     "I will try to figure out what went wrong.").arg(strerror(errno)));
+    KMessageBox::error(timemon, i18n("Unable to initialize the 'kstat' library. "
+                                     "This library is used for accessing kernel information. "
+                                     "The diagnostics are:\n%1.\n"
+                                     "Are you really running Solaris? "
+                                     "Please contact the maintainer at mueller@kde.org "
+                                     "who will try to figure out what went wrong.").arg(strerror(errno)));
     exit(1);
   }
 #endif
@@ -149,9 +149,9 @@ void KSample::parseMtab(char *dest)
 {
     ifstream *mtab = new ifstream(MTAB_NAME);
     if (!mtab->good()) {
-        KMessageBox::error(timemon, i18n("I cannot open file `%1' to determine where the proc\n"
-                                         "filesystem is mounted. The diagnostics are:\n %2\n\n"
-                                         "Are you running UNIX at all?!?").arg( MTAB_NAME).arg( strerror(errno)));
+        KMessageBox::error(timemon, i18n("Unable to open file '%1' to determine where the proc "
+                                         "filesystem is mounted. The diagnostics are:\n%2\n"
+                                         "Are you really running UNIX?").arg( MTAB_NAME).arg( strerror(errno)));
         exit(1);
     }
 
@@ -164,27 +164,27 @@ void KSample::parseMtab(char *dest)
         mtab->getline(line, sizeof(line));
 
         if (mtab->bad()) {
-            errormsg = i18n("I cannot read file `%1' to determine where the proc\n"
+            errormsg = i18n("Unable to read file '%1' to determine where the proc "
                             "filesystem is mounted. The diagnostics are:\n %2").arg(MTAB_NAME).arg(strerror(errno));
             break;
         }
 
         if (mtab->eof()) {
-            errormsg = i18n("Hmm, I could not figure out where the proc filesystem\n"
-                            "is mounted (there is no entry in `%1').\n\n"
-                            "I need information from the proc filesystem to determine\n"
-                            "current system usage. Maybe you are not running Linux (I'm\n"
-                            "afraid the proc filesystem is Linux specific)?\n\n"
-                            "If you can provide help with porting KTimeMon to your\n"
-                            "platform, please contact me at <mueller@kde.org>").arg(MTAB_NAME);
+            errormsg = i18n("Unable to determine where the proc filesystem "
+                            "is mounted (there is no entry in '%1').\n"
+                            "Information is required from the proc filesystem to "
+                            "determine current system usage. Maybe you are not running "
+			    "Linux (Unfortunately the proc filesystem is Linux specific)?\n"
+                            "If you can provide help with porting KTimeMon to your "
+                            "platform, please contact the maintainer at mueller@kde.org").arg(MTAB_NAME);
             break;
         }
 
-        if (mtab->fail()) {
-            errormsg = i18n("Hmm, I encountered a very long line while reading\n"
-                            "information in `%1' (where \"very long\" is defined\n"
-                            "as > %2). This happened at line %3.\n\n"
-                            "Is %4 the mount table on your platform?\n\n")
+	if (mtab->fail()) {
+            errormsg = i18n("A very long line was encountered while reading "
+                            "information in '%1' (where \"very long\" is defined "
+                            "as > %2). This happened at line %3.\n"
+                            "Is %4 the mount table on your platform?")
                 .arg(MTAB_NAME).arg(sizeof(line)).arg(lineno).arg(MTAB_NAME);
             break;
         }
@@ -252,7 +252,7 @@ void KSample::readSample()
 
     lseek(memFD, 0, 0);
     if ((l = read(memFD, buffer, sizeof(buffer) - 1)) < 0)
-        fatal(i18n("Sorry, I cannot read the memory usage file `%1/%2'.\n"
+        fatal(i18n("Unable to read the memory usage file '%1/%2'.\n"
                    "The diagnostics are: %3").arg(proc).arg(MEMINFO_NAME).arg(strerror(errno)));
 
     buffer[l] = '\0';
@@ -275,17 +275,17 @@ void KSample::readSample()
         p = strstr(buffer, memstats[l].name);
         if (p == 0 ||
             sscanf(p + strlen(memstats[l].name), "%lu kB", memstats[l].stat) < 1)
-            fatal(i18n("Sorry, the memory usage file `%1/%2'\nseems to use a "
-                       "different file format than I expect.\n\n"
-                       "Maybe your version of the proc filesystem is\n"
-                       "incompatible with mine. Mail me at\n"
-                       "m.maierhofer@tees.ac.uk and I will try to sort this out.").arg(proc).arg(MEMINFO_NAME));
+            fatal(i18n("The memory usage file '%1/%2' seems to use a "
+                       "different file format than expected.\n"
+                       "Maybe your version of the proc filesystem is "
+                       "incompatible with supported versions. "
+		       "Please contact the developer at m.maierhofer@tees.ac.uk who will try to sort this out.").arg(proc).arg(MEMINFO_NAME));
         l++;
     }
 
     lseek(statFD, 0, 0);
     if ((l = read(statFD, buffer, sizeof(buffer)-1)) < 0)
-        fatal(i18n("Sorry, I cannot read the system usage file `%1/%2'.\n"
+        fatal(i18n("Unable to read the system usage file '%1/%2'.\n"
                    "The diagnostics are: %3").arg(proc).arg(STAT_NAME).arg(strerror(errno)));
 
     buffer[l] = '\0';
@@ -326,19 +326,19 @@ void KSample::readSample()
     }
 
     if (!ok)
-        fatal(i18n("Sorry, the system usage file `%1/%2'\n"
-                   "seems to use a different file format than I expect.\n\n"
-                   "Maybe your version of the proc filesystem is\n"
-                   "incompatible with mine. Mail me at\n"
-                   "mueller@kde.org and I will try to sort this out.").arg(proc).arg(STAT_NAME));
+        fatal(i18n("The system usage file '%1/%2' "
+                   "seems to use a different file format than expected.\n"
+                   "Maybe your version of the proc filesystem is "
+                   "incompatible with supported versions. "
+		   "Please contact the maintainer at mueller@kde.org who will try to sort this out.").arg(proc).arg(STAT_NAME));
 
 #elif defined(__osf__)          // in OSF/2, we can use table()
 
-    QString msg = i18n("Sorry, I cannot get system information.\n\n"
-                       "The table(2) system call returned an error\n"
-                       "for table %1.\n\n"
-                       "You may want to mail me at mueller@kde.org, "
-                       "I will try to figure out what went wrong.");
+    QString msg = i18n("Unable to obtain system information.\n"
+                       "The table(2) system call returned an error "
+                       "for table %1.\n"
+                       "Please contact the maintainer at mueller@kde.org "
+		       "who will try to figure out what went wrong.");
 
     struct tbl_sysinfo sysinfo;
     if (table(TBL_SYSINFO, 0, &sysinfo, 1, sizeof(sysinfo)) != 1)
@@ -389,10 +389,10 @@ void KSample::readSample()
     }
 
     if (sample.cpus == 0)
-        fatal(i18n("Sorry, I cannot find any entries for CPU statistics\n"
-                   "in the `kstat' library. Are you running a non-standard\n"
-                   "version of Solaris?\n\n"
-                   "Please contact me at mueller@kde.org and I will try to sort this out."));
+        fatal(i18n("Unable to find any entries for CPU statistics "
+                   "in the 'kstat' library. Are you running a non-standard "
+                   "version of Solaris?\n"
+                   "Please contact the maintainer at mueller@kde.org who will try to sort this out."));
 
     sample.user = sample.nice = sample.kernel = sample.idle = 0;
     sample.pin = sample.pout = sample.swin = sample.swout = 0;
@@ -407,10 +407,9 @@ void KSample::readSample()
         cpu_stat_t cstat;
         if (kstat_read(kc, ksp, 0) == -1 || // update from kernel
             kstat_read(kc, ksp, &cstat) == -1) // and read into buffer
-            fatal(i18n("Sorry, I cannot read the CPU statistics entry\n"
-                       "from the `kstat' library. The diagnostics are `%1'.\n\n"
-                       "You might want to contact me at\n"
-                       "mueller@kde.org and I will try to sort this out.").arg(strerror(errno)));
+            fatal(i18n("Unable to read the CPU statistics entry "
+                       "from the 'kstat' library. The diagnostics are '%1'.\n"
+                       "Please contact the maintainer at mueller@kde.org who will try to sort this out.").arg(strerror(errno)));
 
         // fields are: idle user kernel iowait
         sample.user += cstat.cpu_sysinfo.cpu[1] / sample.cpus;
@@ -427,11 +426,10 @@ void KSample::readSample()
     }
 
     if (cpus != sample.cpus)
-        fatal(i18n("Huhh, now this is very strange.\n"
-                   "The number of CPUs seems to have changed at\n"
-                   "very short notice. Or the `kstat' library returns\n"
+        fatal(i18n("The number of CPUs appears to have changed at "
+                   "very short notice, or the 'kstat' library returns "
                    "inconsistent results (%1 vs. %2 CPUs).\n"
-                   "Please contact me at mueller@kde.org and I will try to sort this out.").arg(sample.cpus).arg(cpus));
+                   "Please contact the maintainer at mueller@kde.org who will try to sort this out.").arg(sample.cpus).arg(cpus));
 
     // availrmem = pages of core for user-proc ( == physmem - kernelmem)
     // freemem = no of free pages
@@ -440,10 +438,10 @@ void KSample::readSample()
     errno = 0;
     if ((ksp = kstat_lookup(kc, "unix", -1, "system_pages")) == 0 ||
         kstat_read(kc, ksp, 0) == -1)
-        fatal(i18n("Sorry, I cannot read the memory statistics entry\n"
-                   "from the `kstat' library. The diagnostics are `%1'\n\n"
-                   "You might want to contact me at\n"
-                   "mueller@kde.org and I will try to sort this out.").arg(strerror(errno)));
+        fatal(i18n("Unable to read the memory statistics entry "
+                   "from the 'kstat' library. The diagnostics are '%1'\n"
+                   "You might want to contact the maintainer at "
+                   "mueller@kde.org who will try to sort this out.").arg(strerror(errno)));
 
     int i;
     unsigned long physmem = 0, freemem = 0, availrmem = 0;
@@ -457,10 +455,10 @@ void KSample::readSample()
     }
 
     if (physmem == 0)           // sanity check, this should always be > 0
-        fatal(i18n("Uh uh, there seems to be a problem with my handling\n"
-                   "of the `kstat' library: I determined 0 physical memory!\n"
-                   "(Free memory is %1, available memory is %2.\n\n"
-                   "Please contact me at mueller@kde.org and I will try to sort this out.").arg(freemem).arg(availrmem));
+        fatal(i18n("There seems to be a problem with KTimeMon's handling "
+                   "of the 'kstat' library: 0 bytes of physical memory determined!\n"
+                   "Free memory is %1, available memory is %2.\n"
+                   "Please contact the maintainer at mueller@kde.org who will try to sort this out.").arg(freemem).arg(availrmem));
 
     sample.mtotal = physmem;
     sample.free = freemem;
@@ -469,19 +467,19 @@ void KSample::readSample()
 
     int swapentries;
     if ((swapentries = swapctl(SC_GETNSWP, 0)) == -1)
-        fatal(i18n("Sorry, cannot determine the number of\n"
-                   "swap spaces. The diagnostics are `%1'.\n\n"
-                   "Please contact me at mueller@kde.org and I will try to sort this out.").arg(strerror(errno)));
+        fatal(i18n("Unable to determine the number of "
+                   "swap spaces. The diagnostics are '%1'.\n"
+                   "Please contact the maintainer at mueller@kde.org who will try to sort this out.").arg(strerror(errno)));
 
     if (swapentries != 0) {
                                 // 2* to get some space for padding??
         swaptbl_t *stbl = (swaptbl_t *) malloc(2*sizeof(int) + swapentries *
                                                sizeof(struct swapent));
         if (stbl == 0)
-            fatal(i18n("Sorry, I ran out of memory while\n"
+            fatal(i18n("KTimeMon ran out of memory while "
                        "trying to determine the swap usage.\n"
-                       "I tried to allocate %1 bytes of memory (2 * %2 + %3 * %4).\n\n"
-                       "Please contact me at mueller@kde.org and I will try to sort this out.")
+                       "Attempted to allocate %1 bytes of memory (2 * %2 + %3 * %4).\n"
+                       "Please contact the maintainer at mueller@kde.org who will try to sort this out.")
                   .arg(2 * sizeof(int) + swapentries * sizeof(struct swapent))
                   .arg(sizeof(int)).arg(swapentries).arg(sizeof(struct swapent)));
 
@@ -490,17 +488,17 @@ void KSample::readSample()
         for (i = 0; i < swapentries; i++) stbl->swt_ent[i].ste_path = path;
 
         if ((swapentries = swapctl(SC_LIST, stbl)) == -1)
-            fatal(i18n("Sorry, I cannot determine the swap usage.\n"
-                       "The diagnostics are `%1'.\n\n"
-                       "Please contact me at mueller@kde.org and I will try to sort this out.").arg(strerror(errno)));
+            fatal(i18n("Unable to determine the swap usage.\n"
+                       "The diagnostics are '%1'.\n"
+                       "Please contact the maintainer at mueller@kde.org who will try to sort this out.").arg(strerror(errno)));
 
 
         if (!warned && swapentries != stbl->swt_n) {
             warned = true;
-            nonfatal(i18n("Strange, I requested information for\n"
-                          "%1 swap spaces, but only got %2 swap entries back.\n"
-                          "I am a bit confused now, but I will try to continue.\n\n"
-                          "Please contact me at mueller@kde.org and I will try to sort this out.").arg(stbl->swt_n).arg(swapentries));
+            nonfatal(i18n("Information was requested for "
+                          "%1 swap spaces, but only %2 swap entries were returned.\n"
+                          "KTimeMon will attempt to continue.\n"
+                          "Please contact the maintainer at mueller@kde.org who will try to sort this out.").arg(stbl->swt_n).arg(swapentries));
         }
 
         for (i = 0; i < swapentries; i++) {
