@@ -16,49 +16,51 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: domtreeview.cpp,v 1.15 2001/07/28 22:46:44 schlpbch Exp $ */
+/* $Id: domtreeview.cpp,v 1.20 2002/02/10 14:31:02 schlpbch Exp $ */
 
-#include <assert.h>  
+#include <assert.h>
 
-#include <qapplication.h> 
+#include <qapplication.h>
 #include <qcheckbox.h>
 #include <qlayout.h>
 #include <qfont.h>
 #include <qfile.h>
 
-#include <dom/dom_element.h>  
+#include <dom/dom_element.h>
 #include <dom/dom_node.h>
 
-#include <kfiledialog.h>   
+#include <kfiledialog.h>
 #include <kmessagebox.h>
 #include <khtml_part.h>
 #include <klocale.h>
+#include <kglobalsettings.h>
 #include <kdebug.h>
 
 #include "domtreeview.h"
+#include <qpushbutton.h>
 
-DOMTreeView::DOMTreeView(QWidget *parent, KHTMLPart *_part, const char* name, bool allowSaving) 
+DOMTreeView::DOMTreeView(QWidget *parent, KHTMLPart *_part, const char* name, bool allowSaving)
   : KDialog(parent, name), m_expansionDepth(5), m_maxDepth(0),
     m_bPure(true), m_bShowAttributes(true), m_bHighlightHTML(true),
     m_findDialog(0)
-{  
+{
   part = _part;
 
   setCaption( i18n( "DOM Tree for %1" ).arg(part->url().url()) );
   setMinimumHeight(600);
   setMinimumWidth(400);
 
-  m_vLayout1 = new QVBoxLayout( this ); 
+  m_vLayout1 = new QVBoxLayout( this );
   m_vLayout1->setSpacing( 2 );
 
   m_listView = new KListView( this );
   m_listView->setFocusPolicy( QWidget::ClickFocus );
   m_vLayout1->addWidget( m_listView );
 
-  m_vLayout2 = new QVBoxLayout; 
+  m_vLayout2 = new QVBoxLayout;
   m_vLayout2->setMargin( 8 );
 
-  m_hLayout1 = new QHBoxLayout; 
+  m_hLayout1 = new QHBoxLayout;
   m_hLayout1->setSpacing( 2 );
   m_hLayout1->setMargin( 1 );
 
@@ -69,9 +71,9 @@ DOMTreeView::DOMTreeView(QWidget *parent, KHTMLPart *_part, const char* name, bo
   m_hLayout1->addWidget( m_pureCheckBox );
 
   m_showAttributesCheckBox = new QCheckBox( this );
-  m_showAttributesCheckBox->setText( i18n( "Show &Attributes" ) ); 
+  m_showAttributesCheckBox->setText( i18n( "Show &Attributes" ) );
   m_showAttributesCheckBox->setChecked(m_bShowAttributes);
-  connect(m_showAttributesCheckBox, SIGNAL(toggled(bool)), this, 
+  connect(m_showAttributesCheckBox, SIGNAL(toggled(bool)), this,
 	  SLOT(slotShowAttributesToggled(bool)));
   m_hLayout1->addWidget( m_showAttributesCheckBox );
 
@@ -94,11 +96,11 @@ DOMTreeView::DOMTreeView(QWidget *parent, KHTMLPart *_part, const char* name, bo
   m_increaseButton->setText( "&>" );
   connect(m_increaseButton, SIGNAL(clicked()), this, SLOT(slotIncrExpansionDepth()));
 
-  m_hLayout1->addWidget( m_increaseButton ); 
+  m_hLayout1->addWidget( m_increaseButton );
 
   m_vLayout2->addLayout( m_hLayout1 );
 
-  m_hLayout2 = new QHBoxLayout; 
+  m_hLayout2 = new QHBoxLayout;
   m_hLayout2->setSpacing( 2 );
   m_hLayout2->setMargin( 2 );
 
@@ -109,14 +111,14 @@ DOMTreeView::DOMTreeView(QWidget *parent, KHTMLPart *_part, const char* name, bo
 
   QSpacerItem* spacer2 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
   m_hLayout2->addItem( spacer2 );
-  
+
   if (allowSaving) {
     m_saveButton = new QPushButton( this );
     m_saveButton->setText( i18n( "&Save as HTML" ) );
     connect(m_saveButton, SIGNAL(clicked()), this, SLOT(slotSaveClicked()));
     m_hLayout2->addWidget( m_saveButton );
   }
-  
+
   m_refreshButton = new QPushButton( this );
   m_refreshButton->setText( i18n( "&Refresh" ) );
   connect(m_refreshButton, SIGNAL(clicked()), this, SLOT(slotRefreshClicked()));
@@ -131,7 +133,7 @@ DOMTreeView::DOMTreeView(QWidget *parent, KHTMLPart *_part, const char* name, bo
   m_vLayout2->addLayout( m_hLayout2 );
   m_vLayout1->addLayout( m_vLayout2 );
 
-  const QFont font("Helvetica", 8);
+  const QFont font(KGlobalSettings::generalFont());
   m_listView->setFont( font );
   m_listView->setRootIsDecorated(true);
   m_listView->addColumn("DOM-Tree");
@@ -139,14 +141,14 @@ DOMTreeView::DOMTreeView(QWidget *parent, KHTMLPart *_part, const char* name, bo
   m_rootListView = m_listView;
 
   connect(m_listView, SIGNAL(clicked(QListViewItem *)), this,
-	  SLOT(slotItemClicked(QListViewItem *))); 
+	  SLOT(slotItemClicked(QListViewItem *)));
 
-  connect(part, SIGNAL(nodeActivated(const DOM::Node &)), this, 
+  connect(part, SIGNAL(nodeActivated(const DOM::Node &)), this,
 	  SLOT(slotShowNode(const DOM::Node &)));
- 
+
   m_nodedict.setAutoDelete(true);
 
-  slotShowTree(part->document());  
+  slotShowTree(part->document());
 }
 
 DOMTreeView::~DOMTreeView()
@@ -159,7 +161,7 @@ void DOMTreeView::slotShowNode(const DOM::Node &pNode)
 {
   if (m_itemdict[pNode.handle()]) {
     m_listView->setCurrentItem(m_itemdict[pNode.handle()]);
-    m_listView->ensureItemVisible(m_itemdict[pNode.handle()]); 
+    m_listView->ensureItemVisible(m_itemdict[pNode.handle()]);
   }
 }
 
@@ -169,39 +171,40 @@ void DOMTreeView::slotShowTree(const DOM::Node &pNode)
   m_itemdict.clear();
   m_nodedict.clear();
 
-  if(pNode.ownerDocument().isNull()) {
-    showRecursive(0, pNode, 0);
-  } else {
-    showRecursive(0, pNode.ownerDocument(), 0);    
+  DOM::Node child = pNode.firstChild();
+  while(!child.isNull()) {
+    showRecursive(0, child, 0);
+    child = child.nextSibling();
   }
+
   m_maxDepth--;
-  //kdDebug() << " Max Depth: " << m_maxDepth << endl;   
+  //kdDebug() << " Max Depth: " << m_maxDepth << endl;
 }
 
 void DOMTreeView::showRecursive(const DOM::Node &pNode, const DOM::Node &node, uint depth)
 {
   DOMListViewItem *cur_item;
-  
+
   if (depth > m_maxDepth) {
     m_maxDepth = depth;
   }
 
-  if (pNode.ownerDocument() != m_document) {
-    cur_item = new DOMListViewItem(m_listView); 
+  if (depth == 0) {
+    cur_item = new DOMListViewItem(m_listView);
     m_document = pNode.ownerDocument();
   } else {
-    cur_item = new DOMListViewItem(m_itemdict[pNode.handle()]); 
-  } 
+    cur_item = new DOMListViewItem(m_itemdict[pNode.handle()]);
+  }
 
-  //kdDebug() << node.nodeName().string() << " [" << depth << "]" << endl;   
+  //kdDebug() << node.nodeName().string() << " [" << depth << "]" << endl;
   addElement (node, cur_item, false);
   cur_item->setOpen(depth < m_expansionDepth);
-  
+
   if(node.handle()) {
     m_itemdict.insert(node.handle(), cur_item);
     m_nodedict.insert(cur_item, new DOM::Node(node));
   }
-  
+
   DOM::Node child = node.lastChild();
   depth++;
   while(!child.isNull()) {
@@ -210,16 +213,15 @@ void DOMTreeView::showRecursive(const DOM::Node &pNode, const DOM::Node &node, u
   }
 
   const DOM::Element element = static_cast<const DOM::Element>(node);
-
   if (!m_bPure) {
     if (!(element.isNull()) && (!(element.firstChild().isNull()))) {
-      if(pNode.ownerDocument() != m_document) {
-	cur_item = new DOMListViewItem(m_listView, cur_item); 
+      if(depth == 1) {
+	cur_item = new DOMListViewItem(m_listView, cur_item);
 	m_document = pNode.ownerDocument();
       } else {
-	cur_item = new DOMListViewItem(m_itemdict[pNode.handle()], cur_item); 
+	cur_item = new DOMListViewItem(m_itemdict[pNode.handle()], cur_item);
       }
-      //kdDebug() << "</" << node.nodeName().string() << ">" << endl;    
+      //kdDebug() << "</" << node.nodeName().string() << ">" << endl;
       addElement(element, cur_item, true);
       cur_item->setOpen(depth < m_expansionDepth);
     }
@@ -227,9 +229,9 @@ void DOMTreeView::showRecursive(const DOM::Node &pNode, const DOM::Node &node, u
 }
 
 void DOMTreeView::addElement ( const DOM::Node &node,  DOMListViewItem *cur_item, bool isLast)
-{  
+{
   const QString nodeName(node.nodeName().string());
-  QString text; 
+  QString text;
   const DOM::Element element = static_cast<const DOM::Element> (node);
   if (!element.isNull()) {
     if (!m_bPure) {
@@ -242,7 +244,7 @@ void DOMTreeView::addElement ( const DOM::Node &node,  DOMListViewItem *cur_item
     } else {
       text = nodeName;
     }
-  
+
     if (m_bShowAttributes && !isLast) {
       QString attributes;
       DOM::Attr attr;
@@ -257,7 +259,7 @@ void DOMTreeView::addElement ( const DOM::Node &node,  DOMListViewItem *cur_item
       }
       text += attributes.simplifyWhiteSpace();
     }
-    
+
     if (!m_bPure) {
       if(element.firstChild().isNull()) {
 	text += "/>";
@@ -271,110 +273,110 @@ void DOMTreeView::addElement ( const DOM::Node &node,  DOMListViewItem *cur_item
 
     // Hacks to deal with PRE
     QTextStream ts( text, IO_ReadOnly );
-    while (!ts.eof()) {  
-      const QString txt(ts.readLine()); 
-      const QFont font("Courier", 8);
+    while (!ts.eof()) {
+      const QString txt(ts.readLine());
+      const QFont font(KGlobalSettings::fixedFont());
       cur_item->setFont( font );
       cur_item->setNamedColor("#444444");
       cur_item->setText(0, txt);
-  
+
       if(node.handle()) {
 	m_itemdict.insert(node.handle(), cur_item);
 	m_nodedict.insert(cur_item, new DOM::Node(node));
       }
-      
+
       DOMListViewItem *parent;
       if (cur_item->parent()) {
 	parent = static_cast<DOMListViewItem *>(cur_item->parent());
       } else {
 	parent = cur_item;
       }
-      cur_item = new DOMListViewItem(parent, cur_item); 
+      cur_item = new DOMListViewItem(parent, cur_item);
     }
     // This is one is too much
-    DOMListViewItem *notLastItem = static_cast<DOMListViewItem *>(cur_item->itemAbove()); 
+    DOMListViewItem *notLastItem = static_cast<DOMListViewItem *>(cur_item->itemAbove());
     delete cur_item;
     cur_item = notLastItem;
   }
-  
+
   if (m_bHighlightHTML) {
     highlightHTML(cur_item, nodeName);
   }
 }
 
-void DOMTreeView::highlightHTML(DOMListViewItem * cur_item, const QString& nodeType)
+void DOMTreeView::highlightHTML(DOMListViewItem *cur_item, const QString &nodeName)
 {
   /* This is slow. I could make it O(1) be using the tokenizer of khtml but I don't
    * think it's worth it.
    */
 
   QString namedColor("#000000");
-
-  if ( nodeType == "HTML" ) {
+  QString tagName = nodeName.upper();
+  if ( tagName == "HTML" ) {
     namedColor = "#0000ff";
     cur_item->setBold(true);
-  } else if ( nodeType == "HEAD" ) {
+  } else if ( tagName == "HEAD" ) {
     namedColor = "#0022ff";
     cur_item->setBold(true);
 
-  } else if ( nodeType == "TITLE" ) {
+  } else if ( tagName == "TITLE" ) {
     namedColor = "#2200ff";
-  } else if ( nodeType == "SCRIPT" ) {
+  } else if ( tagName == "SCRIPT" ) {
     namedColor = "#4400ff";
-  } else if ( nodeType == "NOSCRIPT" ) {
+  } else if ( tagName == "NOSCRIPT" ) {
     namedColor = "#0044ff";
-  } else if ( nodeType == "STYLE" ) {
+  } else if ( tagName == "STYLE" ) {
     namedColor = "#0066ff";
-  } else if ( nodeType == "LINK" ) {
+  } else if ( tagName == "LINK" ) {
     namedColor = "#6600ff";
-  } else if ( nodeType == "META" ) {
-    namedColor = "#0088ff"; 
+  } else if ( tagName == "META" ) {
+    namedColor = "#0088ff";
 
-  } else if ( nodeType == "BODY" ) {
+  } else if ( tagName == "BODY" ) {
     namedColor = "#ff0000";
     cur_item->setBold(true);
-  } else if ( nodeType == "A" || nodeType == "IMG") {
-    namedColor = "magenta"; 
+  } else if ( tagName == "A" || tagName == "IMG") {
+    namedColor = "magenta";
     cur_item->setUnderline(true);
 
-  } else if ( nodeType == "DIV" ) {
+  } else if ( tagName == "DIV" ) {
     namedColor = "#ff0044";
-  } else if ( nodeType == "SPAN" ) {
+  } else if ( tagName == "SPAN" ) {
     namedColor = "#ff4400";
-  } else if ( nodeType == "P" ) {
+  } else if ( tagName == "P" ) {
     namedColor = "#ff0066";
 
-  } else if ( nodeType == "DL" || nodeType == "OL"|| nodeType == "UL" || nodeType == "TABLE" ) {
+  } else if ( tagName == "DL" || tagName == "OL"|| tagName == "UL" || tagName == "TABLE" ) {
     namedColor = "#880088";
-  } else if ( nodeType == "LI" ) {
+  } else if ( tagName == "LI" ) {
     namedColor = "#884488";
-  } else if ( nodeType == "TBODY" ){
+  } else if ( tagName == "TBODY" ){
     namedColor = "#888888";
-  } else if ( nodeType == "TR" ) {
+  } else if ( tagName == "TR" ) {
     namedColor = "#882288";
-  } else if ( nodeType == "TD" ) {
+  } else if ( tagName == "TD" ) {
     namedColor = "#886688";
 
-  } else if ((nodeType == "H1")||(nodeType == "H2")||(nodeType == "H3") ||
-	     (nodeType == "H4")||(nodeType == "H5")||(nodeType == "H6")) {  
+  } else if ((tagName == "H1")||(tagName == "H2")||(tagName == "H3") ||
+	     (tagName == "H4")||(tagName == "H5")||(tagName == "H6")) {
     namedColor = "#008800";
-  } else if (nodeType == "HR" ) {  
+  } else if (tagName == "HR" ) {
     namedColor = "#228822";
 
-  } else if ( nodeType == "FRAME" || nodeType == "IFRAME" ) {
+  } else if ( tagName == "FRAME" || tagName == "IFRAME" ) {
     namedColor = "#ff22ff";
-  } else if ( nodeType == "FRAMESET" ) {
+  } else if ( tagName == "FRAMESET" ) {
     namedColor = "#dd22dd";
 
-  } else if ( nodeType == "APPLET" || nodeType == "OBJECT" ) {
+  } else if ( tagName == "APPLET" || tagName == "OBJECT" ) {
     namedColor = "#bb22bb";
 
-  } else if ( nodeType == "BASEFONT" || nodeType == "FONT" ) {
+  } else if ( tagName == "BASEFONT" || tagName == "FONT" ) {
     namedColor = "#097200";
- 
-  } else if ( (nodeType == "B") || (nodeType == "I") ) {  
+
+  } else if ( (tagName == "B") || (tagName == "I") ) {
     cur_item->setBold(true);
-  } else if ( nodeType == "U") {  
+  } else if ( tagName == "U") {
     cur_item->setUnderline(true);
   }
 
@@ -393,7 +395,7 @@ void DOMTreeView::slotFindClicked()
 {
   if (m_findDialog == 0) {
     m_findDialog = new KEdFind(this);
-    connect(m_findDialog, SIGNAL(search()), this, SLOT(slotSearch()));   
+    connect(m_findDialog, SIGNAL(search()), this, SLOT(slotSearch()));
   }
   m_findDialog->show();
 }
@@ -404,21 +406,21 @@ void DOMTreeView::slotSearch()
   const QString& searchText = m_findDialog->getText();
   bool caseSensitive = m_findDialog->case_sensitive();
 
-  searchRecursive(static_cast<DOMListViewItem*>(m_rootListView->firstChild()), 
-		  searchText, caseSensitive);  
+  searchRecursive(static_cast<DOMListViewItem*>(m_rootListView->firstChild()),
+		  searchText, caseSensitive);
 
   m_findDialog->hide();
 }
 
-void DOMTreeView::searchRecursive(DOMListViewItem* cur_item, const QString& searchText, 
+void DOMTreeView::searchRecursive(DOMListViewItem* cur_item, const QString& searchText,
 				  bool caseSensitive)
 {
-  const QString text(cur_item->text(0)); 
-  if (text.contains(searchText, caseSensitive) > 0) { 
+  const QString text(cur_item->text(0));
+  if (text.contains(searchText, caseSensitive) > 0) {
     cur_item->setUnderline(true);
     cur_item->setItalic(true);
     m_listView->setCurrentItem(cur_item);
-    m_listView->ensureItemVisible(cur_item);     
+    m_listView->ensureItemVisible(cur_item);
   } else {
     cur_item->setOpen(false);
   }
@@ -432,13 +434,13 @@ void DOMTreeView::searchRecursive(DOMListViewItem* cur_item, const QString& sear
 
 #if 0
 void DOMTreeView::slotSaveClicked()
-{  
-  //kdDebug() << "void KfingerCSSWidget::slotSaveAs()" << endl;   
+{
+  //kdDebug() << "void KfingerCSSWidget::slotSaveAs()" << endl;
   KURL url = KFileDialog::getSaveFileName( part->url().url(), "*.html",
 					   this, i18n("Save DOM Tree as HTML") );
-  if (!(url.isEmpty()) && url.isValid()) {               
+  if (!(url.isEmpty()) && url.isValid()) {
     QFile file(url.path());
-   
+
     if (file.exists()) {
       const QString title = i18n( "File exists" );
       const QString text = i18n( "Do you really want to overwrite: \n%1" ).arg(url.url());
@@ -450,7 +452,7 @@ void DOMTreeView::slotSaveClicked()
     if (file.open(IO_WriteOnly) ) {
       kdDebug() << "Opened File: " << url.url() << endl;
       m_textStream = new QTextStream(&file); //(stdOut)
-      saveTreeAsHTML(part->document());  
+      saveTreeAsHTML(part->document());
       file.close();
       kdDebug() << "File closed " << endl;
       delete m_textStream;
@@ -459,7 +461,7 @@ void DOMTreeView::slotSaveClicked()
       const QString text = i18n( "Sorry, couldn't open \n %1 \n for writing" ).arg(url.path());
       KMessageBox::sorry( this, text, title );
     }
-  } else {  
+  } else {
     const QString title = i18n( "Invalid URL" );
     const QString text = i18n( "This URL \n %1 \n is not valid." ).arg(url.url());
     KMessageBox::sorry( this, text, title );
@@ -469,13 +471,13 @@ void DOMTreeView::slotSaveClicked()
 void DOMTreeView::saveTreeAsHTML(const DOM::Node &pNode)
 {
   assert(m_textStream);
-  
+
   // Add a doctype
 
   (*m_textStream) <<"<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">" << endl;
   if(pNode.ownerDocument().isNull()) {
     saveRecursive(pNode, 0);
-  } else {    
+  } else {
     saveRecursive(pNode.ownerDocument(), 0);
   }
 }
@@ -483,16 +485,16 @@ void DOMTreeView::saveTreeAsHTML(const DOM::Node &pNode)
 void DOMTreeView::saveRecursive(const DOM::Node &pNode, int indent)
 {
   const QString nodeName(pNode.nodeName().string());
-  QString text; 
+  QString text;
   QString strIndent;
-  strIndent.fill(' ', indent);  
+  strIndent.fill(' ', indent);
   const DOM::Element element = static_cast<const DOM::Element>(pNode);
 
   text = strIndent;
 
   if ( !element.isNull() ) {
     if (nodeName.at(0)=='-') {
-      /* Don't save khtml internal tags '-konq..' 
+      /* Don't save khtml internal tags '-konq..'
        * Approximating it with <DIV>
        */
       text += "<DIV> <!-- -KONG_BLOCK -->";
@@ -510,9 +512,9 @@ void DOMTreeView::saveRecursive(const DOM::Node &pNode, int indent)
       if (!(attributes.isEmpty())){
 	text += " ";
       }
- 
+
       text += attributes.simplifyWhiteSpace();
-  
+
       if(element.firstChild().isNull()) {
 	text += "/>";
       } else {
@@ -520,27 +522,27 @@ void DOMTreeView::saveRecursive(const DOM::Node &pNode, int indent)
       }
     }
   } else {
-    text = strIndent + pNode.nodeValue().string();  
-  }   
+    text = strIndent + pNode.nodeValue().string();
+  }
 
   kdDebug() << text << endl;
-  if (!(text.isEmpty())) {   
+  if (!(text.isEmpty())) {
     (*m_textStream) << text << endl;
   }
-  
+
   DOM::Node child = pNode.firstChild();
   while(!child.isNull()) {
     saveRecursive(child, indent+2);
     child = child.nextSibling();
   }
 
-  if (!(element.isNull()) && (!(element.firstChild().isNull()))) { 
-    if (nodeName.at(0)=='-') { 
+  if (!(element.isNull()) && (!(element.firstChild().isNull()))) {
+    if (nodeName.at(0)=='-') {
       text = strIndent + "</DIV> <!-- -KONG_BLOCK -->";
     } else {
       text = strIndent + "</" + pNode.nodeName().string() + ">";
     }
-    kdDebug() << text << endl;    
+    kdDebug() << text << endl;
     (*m_textStream) << text << endl;
   }
 }
@@ -560,7 +562,7 @@ void DOMTreeView::slotIncrExpansionDepth()
     QApplication::beep();
   }
 }
- 
+
 void DOMTreeView::slotDecrExpansionDepth()
 {
   if (m_expansionDepth > 0) {
@@ -570,8 +572,8 @@ void DOMTreeView::slotDecrExpansionDepth()
     QApplication::beep();
   }
 }
- 
-void DOMTreeView::adjustDepth(QListViewItem* cur_item,  uint currDepth)
+
+void DOMTreeView::adjustDepth(QListViewItem *cur_item,  uint currDepth)
 {
   if (!(cur_item == 0)) {
     while( cur_item ) {
